@@ -6,13 +6,17 @@ import requests
 import socket
 import pandas as pd
 
-sys.tracebacklimit = None
-
 logger = logging.getLogger(__name__)
 
 HOST_IP = socket.gethostbyname(socket.gethostname())
 PORT = 8000
 
+STATUS = "status"
+RESULT = "result"
+ERROR = "error"
+SUCCESS = "SUCCESS"
+FAILED = "FAILED"
+
 ################################################################################
 # Queries
 ################################################################################
@@ -52,11 +56,14 @@ class AthenaClient:
             payload = json.dumps({"user_name": self._user_name, "password": self._password})
             r = requests.post(SERVICE_URL + API_GET_ATHENA_DATABASES, data=payload, headers=HEADERS)
             response = r.json()
-            if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response)
-                return response_as_df
+            if response[STATUS] == SUCCESS:
+                if result_as_df:
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    return response_as_df
+                else:
+                    return response[RESULT]
             else:
-                return response
+                return response[RESULT]
         except requests.exceptions.HTTPError as err_h:
             # logger.error(msg=err_h)
             raise Exception("Http error occurred") from None
@@ -76,23 +83,26 @@ class AthenaClient:
             payload = json.dumps({"user_name": self._user_name, "password": self._password, "schema_name": schema_name})
             r = requests.post(SERVICE_URL + API_GET_ATHENA_TABLES, data=payload, headers=HEADERS)
             response = r.json()
-            if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response)
-                return response_as_df
+            if response[STATUS] == SUCCESS:
+                if result_as_df:
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    return response_as_df
+                else:
+                    return response[RESULT]
             else:
-                return response
+                return response[RESULT]
         except requests.exceptions.HTTPError as err_h:
             # logger.error(msg=err_h)
-            raise Exception("Http error occurred")
+            raise Exception("Http error occurred") from None
         except requests.exceptions.ConnectionError as err_c:
             # logger.error(msg=err_c)
-            raise ConnectionError("Connection error occurred")
+            raise ConnectionError("Connection error occurred") from None
         except requests.exceptions.Timeout as err_t:
             # logger.error(msg=err_t)
-            raise TimeoutError("Request timed out...")
+            raise TimeoutError("Request timed out...") from None
         except requests.exceptions.RequestException as err:
             # logger.error(msg=err)
-            raise Exception("RequestException occurred")
+            raise Exception("RequestException occurred") from None
 
     def top(self, schema_name, table_name, limit=None, result_as_df=True):
         """Returns records from a table"""
@@ -101,23 +111,26 @@ class AthenaClient:
                                   "table_name": table_name, "limit": limit})
             r = requests.post(SERVICE_URL + API_QUERY_ATHENA_TABLE, data=payload, headers=HEADERS)
             response = r.json()
-            if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response)
-                return response_as_df
+            if response[STATUS] == SUCCESS:
+                if result_as_df:
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    return response_as_df
+                else:
+                    return response[RESULT]
             else:
-                return response
+                return response[RESULT]
         except requests.exceptions.HTTPError as err_h:
             # logger.error(msg=err_h)
-            raise Exception("Http error occurred")
+            raise Exception("Http error occurred") from None
         except requests.exceptions.ConnectionError as err_c:
             # logger.error(msg=err_c)
-            raise ConnectionError("Connection error occurred")
+            raise ConnectionError("Connection error occurred") from None
         except requests.exceptions.Timeout as err_t:
             # logger.error(msg=err_t)
-            raise TimeoutError("Request timed out...")
+            raise TimeoutError("Request timed out...") from None
         except requests.exceptions.RequestException as err:
             # logger.error(msg=err)
-            raise Exception("RequestException occurred")
+            raise Exception("RequestException occurred") from None
 
     def run_query(self, query_string, result_as_df=True):
         """Run a specified query"""
@@ -126,20 +139,23 @@ class AthenaClient:
                 {"user_name": self._user_name, "password": self._password, "query_string": query_string})
             r = requests.post(SERVICE_URL + API_RUN_QUERY_ON_ATHENA, data=payload, headers=HEADERS)
             response = r.json()
-            if result_as_df:
-                response_as_df = pd.DataFrame.from_dict(response)
-                return response_as_df
+            if response[STATUS] == SUCCESS:
+                if result_as_df:
+                    response_as_df = pd.DataFrame.from_dict(response[RESULT])
+                    return response_as_df
+                else:
+                    return response[RESULT]
             else:
-                return response
+                return response[RESULT]
         except requests.exceptions.HTTPError as err_h:
             # logger.error(msg=err_h)
-            raise Exception("Http error occurred")
+            raise Exception("Http error occurred") from None
         except requests.exceptions.ConnectionError as err_c:
             # logger.error(msg=err_c)
-            raise ConnectionError("Connection error occurred")
+            raise ConnectionError("Connection error occurred") from None
         except requests.exceptions.Timeout as err_t:
             # logger.error(msg=err_t)
-            raise TimeoutError("Request timed out...")
+            raise TimeoutError("Request timed out...") from None
         except requests.exceptions.RequestException as err:
             # logger.error(msg=err)
-            raise Exception("RequestException occurred")
+            raise Exception("RequestException occurred") from None
